@@ -11,7 +11,7 @@ List EM(NumericVector transitionMatrix, NumericVector emissionArray, NumericVect
   IntegerVector oDims = obsArray.attr("dim"); //k,n,r
 
   arma::cube emission(emissionArray.begin(), eDims[0], eDims[1], eDims[2], true);
-  arma::icube obs(obsArray.begin(), oDims[0], oDims[1], oDims[2], false);
+  arma::icube obs(obsArray.begin(), oDims[0], oDims[1], oDims[2], false, true);
   arma::vec init(initialProbs.begin(), emission.n_rows, true);
   arma::mat transition(transitionMatrix.begin(), emission.n_rows, emission.n_rows, true);
 
